@@ -2,7 +2,7 @@ package DBIx::Class::Loader;
 
 use strict;
 
-our $VERSION = '0.01';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -26,7 +26,7 @@ DBIx::Class::Loader - Dynamic definition of DBIx::Class sub classes.
     inflect                 => { child => 'children' }
   );
   my $class = $loader->find_class('film'); # $class => Data::Film
-  my $obj = $class->retrieve(1);
+  my $obj = $class->find(1);
 
 use with mod_perl
 
